# TODOCLIST - Todoist plugin for CLI

Simple CLI app for check your tasks from todoist

## Installation

You can install app from pip repository: [todoclist](https://pypi.org/project/todoclist/)

Use pip installer:

```bash
pip install todoclist
```

## Basic commands

> At the first launch app ask you to add yor API key.

1. Today tasks

```bash
docli today - show all todays tasks
```

2. Agenda

```bash
docli agenda - show agenda for a week
```

3. All

```bash
docli all - show all your tasks
```

4. Add

```bash
docli add - add new task

---
1 question - task description
2 question - due date
```
